@@ -221,7 +221,6 @@ type curlOption =
   | CURLOPT_SSLVERIFYPEER of bool
   | CURLOPT_CAINFO of string
   | CURLOPT_CAPATH of string
-  | CURLOPT_PASSWDFUNCTION of (string -> int -> (bool * string))
   | CURLOPT_FILETIME of bool
   | CURLOPT_MAXREDIRS of int
   | CURLOPT_MAXCONNECTS of int
@@ -528,9 +527,6 @@ let set_cainfo conn cainfo =
 let set_capath conn capath =
   setopt conn (CURLOPT_CAPATH capath)
 
-let set_passwdfunction conn closure =
-  setopt conn (CURLOPT_PASSWDFUNCTION closure)
-
 let set_filetime conn filetime =
   setopt conn (CURLOPT_FILETIME filetime)
 
@@ -837,7 +833,6 @@ class handle =
     method set_sslverifypeer flag = set_sslverifypeer conn flag
     method set_cainfo cainfo = set_cainfo conn cainfo
     method set_capath capath = set_capath conn capath
-    method set_passwdfunction closure = set_passwdfunction conn closure
     method set_filetime filetime = set_filetime conn filetime
     method set_maxredirs maxredirs = set_maxredirs conn maxredirs
     method set_maxconnects maxconnects = set_maxconnects conn maxconnects
