@@ -221,7 +221,6 @@ type curlOption =
   | CURLOPT_SSLVERIFYPEER of bool
   | CURLOPT_CAINFO of string
   | CURLOPT_CAPATH of string
-  | CURLOPT_PASSWDFUNCTION of (string -> int -> (bool * string))
   | CURLOPT_FILETIME of bool
   | CURLOPT_MAXREDIRS of int
   | CURLOPT_MAXCONNECTS of int
@@ -370,7 +369,6 @@ val set_progressfunction : t -> (float -> float -> float -> float -> bool) -> un
 val set_sslverifypeer : t -> bool -> unit
 val set_cainfo : t -> string -> unit
 val set_capath : t -> string -> unit
-val set_passwdfunction : t -> (string -> int -> (bool * string)) -> unit
 val set_filetime : t -> bool -> unit
 val set_maxredirs : t -> int -> unit
 val set_maxconnects : t -> int -> unit
@@ -502,7 +500,6 @@ class handle :
     method set_sslverifypeer : bool -> unit
     method set_cainfo : string -> unit
     method set_capath : string -> unit
-    method set_passwdfunction : (string -> int -> (bool * string)) -> unit
     method set_filetime : bool -> unit
     method set_maxredirs : int -> unit
     method set_maxconnects : int -> unit
